summaryrefslogtreecommitdiff
path: root/nuttx/arch/arm/src/lpc17xx
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-06-30 18:40:41 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-06-30 18:40:41 -0600
commit8ae1ef74551af33cf18dd1cc4188c4def4fecf42 (patch)
tree42db9eb61e43dd7bd958f080d08cbe6544793d5b /nuttx/arch/arm/src/lpc17xx
parent8299f4051ce03e4c56c08c93a81af0c36e24a2f0 (diff)
downloadnuttx-8ae1ef74551af33cf18dd1cc4188c4def4fecf42.tar.gz
nuttx-8ae1ef74551af33cf18dd1cc4188c4def4fecf42.tar.bz2
nuttx-8ae1ef74551af33cf18dd1cc4188c4def4fecf42.zip
Rename uip_poll->devif_poll and uip_timer->devif_timer
Diffstat (limited to 'nuttx/arch/arm/src/lpc17xx')
-rw-r--r--nuttx/arch/arm/src/lpc17xx/lpc17_ethernet.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/nuttx/arch/arm/src/lpc17xx/lpc17_ethernet.c b/nuttx/arch/arm/src/lpc17xx/lpc17_ethernet.c
index e0093fddb..f38e5c435 100644
--- a/nuttx/arch/arm/src/lpc17xx/lpc17_ethernet.c
+++ b/nuttx/arch/arm/src/lpc17xx/lpc17_ethernet.c
@@ -647,7 +647,7 @@ static int lpc17_transmit(struct lpc17_driver_s *priv)
*
* Description:
* The transmitter is available, check if uIP has any outgoing packets ready
* to send. This is a callback from uip_poll(). uip_poll() may be called:
*
* 1. When the preceding TX packet send is complete,
* 2. When the preceding TX packet send timesout and the interface is reset
@@ -977,7 +977,7 @@ static void lpc17_txdone(struct lpc17_driver_s *priv)
else
{
- (void)uip_poll(&priv->lp_dev, lpc17_uiptxpoll);
+ (void)devif_poll(&priv->lp_dev, lpc17_uiptxpoll);
}
}
@@ -1188,7 +1188,7 @@ static void lpc17_txtimeout(int argc, uint32_t arg, ...)
/* Then poll uIP for new XMIT data */
- (void)uip_poll(&priv->lp_dev, lpc17_uiptxpoll);
+ (void)devif_poll(&priv->lp_dev, lpc17_uiptxpoll);
}
}
@@ -1225,7 +1225,7 @@ static void lpc17_polltimer(int argc, uint32_t arg, ...)
* we will missing TCP time state updates?
*/
- (void)uip_timer(&priv->lp_dev, lpc17_uiptxpoll, LPC17_POLLHSEC);
+ (void)devif_timer(&priv->lp_dev, lpc17_uiptxpoll, LPC17_POLLHSEC);
}
/* Setup the watchdog poll timer again */
@@ -1482,7 +1482,7 @@ static int lpc17_txavail(struct net_driver_s *dev)
{
/* If so, then poll uIP for new XMIT data */
- (void)uip_poll(&priv->lp_dev, lpc17_uiptxpoll);
+ (void)devif_poll(&priv->lp_dev, lpc17_uiptxpoll);
}
}
@@ -647,7 +647,7 @@ static int lpc17_transmit(struct lpc17_driver_s *priv)
* Description:
* The transmitter is available, check if uIP has any outgoing packets ready
- * to send. This is a callback from uip_poll(). uip_poll() may be called:
+ * to send. This is a callback from devif_poll(). devif_poll() may be called:
*
* 1. When the preceding TX packet send is complete,